import * as eslint from 'eslint';
import { PackageJsonRuleContext } from '../createRule.mjs';
import * as jsonc_eslint_parser from 'jsonc-eslint-parser';
import 'estree';

declare const recommended: {
    files: string[];
    languageOptions: {
        parser: typeof jsonc_eslint_parser;
    };
    plugins: {
        readonly "package-json": {
            meta: {
                name: string;
                version: string;
            };
            rules: {
                "order-properties": {
                    create(context: PackageJsonRuleContext<[({
                        order: "legacy" | "sort-package-json";
                    } | undefined)?]>): jsonc_eslint_parser.RuleListener;
                    meta: eslint.Rule.RuleMetaData;
                };
                "prefer-repository-shorthand": {
                    create(context: PackageJsonRuleContext<unknown[]>): jsonc_eslint_parser.RuleListener;
                    meta: eslint.Rule.RuleMetaData;
                };
                "sort-collections": {
                    create(context: PackageJsonRuleContext<string[]>): jsonc_eslint_parser.RuleListener;
                    meta: eslint.Rule.RuleMetaData;
                };
                "unique-dependencies": {
                    create(context: PackageJsonRuleContext<unknown[]>): jsonc_eslint_parser.RuleListener;
                    meta: eslint.Rule.RuleMetaData;
                };
                "valid-local-dependency": {
                    create(context: PackageJsonRuleContext<unknown[]>): jsonc_eslint_parser.RuleListener;
                    meta: eslint.Rule.RuleMetaData;
                };
                "valid-name": {
                    create(context: PackageJsonRuleContext<unknown[]>): jsonc_eslint_parser.RuleListener;
                    meta: eslint.Rule.RuleMetaData;
                };
                "valid-package-def": {
                    create(context: PackageJsonRuleContext<unknown[]>): jsonc_eslint_parser.RuleListener;
                    meta: eslint.Rule.RuleMetaData;
                };
                "valid-repository-directory": {
                    create(context: PackageJsonRuleContext<unknown[]>): jsonc_eslint_parser.RuleListener;
                    meta: eslint.Rule.RuleMetaData;
                };
                "valid-version": {
                    create(context: PackageJsonRuleContext<unknown[]>): jsonc_eslint_parser.RuleListener;
                    meta: eslint.Rule.RuleMetaData;
                };
            };
        };
    };
    rules: {
        [k: string]: "error";
    };
};

export { recommended as default };
