"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var prefer_repository_shorthand_exports = {};
__export(prefer_repository_shorthand_exports, {
  rule: () => rule
});
module.exports = __toCommonJS(prefer_repository_shorthand_exports);
var import_createRule = require("../createRule.js");
var import_findPropertyWithKeyValue = require("../utils/findPropertyWithKeyValue.js");
const githubUrlRegex = /^(?:git\+)?(?:ssh:\/\/git@|http?s:\/\/)?(?:www\.)?github\.com\//;
const isGitHubUrl = (url) => githubUrlRegex.test(url);
const cleanGitHubUrl = (url) => url.replace(githubUrlRegex, "").replace(/\.git$/, "");
const rule = (0, import_createRule.createRule)({
  create(context) {
    return {
      JSONProperty(node) {
        if (node.key.type !== "JSONLiteral" || node.key.value !== "repository" || node.parent.parent.parent.type !== "Program") {
          return;
        }
        if (node.value.type === "JSONObjectExpression") {
          const { properties } = node.value;
          if ((0, import_findPropertyWithKeyValue.findPropertyWithKeyValue)(properties, "directory")) {
            return;
          }
          const typeProperty = (0, import_findPropertyWithKeyValue.findPropertyWithKeyValue)(
            properties,
            "type"
          );
          if (typeProperty?.value.type !== "JSONLiteral" || typeProperty.value.value !== "git") {
            return;
          }
          const urlProperty = (0, import_findPropertyWithKeyValue.findPropertyWithKeyValue)(
            properties,
            "url"
          );
          if (urlProperty?.value.type !== "JSONLiteral" || typeof urlProperty.value.value !== "string" || !isGitHubUrl(urlProperty.value.value)) {
            return;
          }
          const url = urlProperty.value.value;
          context.report({
            fix(fixer) {
              return fixer.replaceText(
                node.value,
                JSON.stringify(cleanGitHubUrl(url))
              );
            },
            messageId: "preferShorthand",
            node: node.value
          });
        }
        if (node.value.type === "JSONLiteral") {
          const { value } = node.value;
          if (typeof value === "string" && isGitHubUrl(value)) {
            context.report({
              fix(fixer) {
                return fixer.replaceText(
                  node.value,
                  JSON.stringify(cleanGitHubUrl(value))
                );
              },
              messageId: "preferShorthand",
              node: node.value
            });
          }
        }
      }
    };
  },
  meta: {
    docs: {
      category: "Best Practices",
      description: "Enforce shorthand declaration for GitHub repository.",
      recommended: true
    },
    fixable: "code",
    messages: {
      preferShorthand: "Prefer a shorthand locator for a GitHub repository."
    }
  }
});
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  rule
});
//# sourceMappingURL=prefer-repository-shorthand.js.map