"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var sort_collections_exports = {};
__export(sort_collections_exports, {
  rule: () => rule
});
module.exports = __toCommonJS(sort_collections_exports);
var import_createRule = require("../createRule.js");
const defaultCollections = [
  "scripts",
  "devDependencies",
  "dependencies",
  "peerDependencies",
  "config"
];
const rule = (0, import_createRule.createRule)({
  create(context) {
    const toSort = context.options[0] || defaultCollections;
    return {
      "JSONProperty:exit"(node) {
        const { key, value } = node;
        const collection = value;
        if (collection.type === "JSONObjectExpression" && toSort.includes(key.value)) {
          const currentOrder = collection.properties;
          const desiredOrder = currentOrder.slice().sort(
            (a, b) => a.key.value > b.key.value ? 1 : -1
          );
          if (currentOrder.some(
            (property, i) => desiredOrder[i] !== property
          )) {
            context.report({
              data: {
                key: key.value
              },
              fix(fixer) {
                return fixer.replaceText(
                  collection,
                  JSON.stringify(
                    desiredOrder.reduce((out, property) => {
                      out[property.key.value] = JSON.parse(
                        context.sourceCode.getText(
                          property.value
                        )
                      );
                      return out;
                    }, {}),
                    null,
                    2
                  ).split("\n").join("\n  ")
                  // nest indents
                );
              },
              loc: collection.loc,
              message: "Package {{ key }} are not alphabetized",
              node
            });
          }
        }
      }
    };
  },
  meta: {
    docs: {
      category: "Best Practices",
      description: "Dependencies, scripts, and configuration values must be declared in alphabetical order.",
      recommended: true
    },
    fixable: "code",
    schema: [
      {
        items: {
          type: "string"
        },
        type: "array"
      }
    ]
  }
});
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  rule
});
//# sourceMappingURL=sort-collections.js.map